
From: Adrian Bunk <bunk@stusta.de>

The patch below makes the needlessly global function ext2_xattr_list 
static.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/ext2/xattr.c |   24 ++++++++++++------------
 25-akpm/fs/ext2/xattr.h |    7 -------
 2 files changed, 12 insertions(+), 19 deletions(-)

diff -puN fs/ext2/xattr.c~fs-ext2-xattrc-make-ext2_xattr_list-static fs/ext2/xattr.c
--- 25/fs/ext2/xattr.c~fs-ext2-xattrc-make-ext2_xattr_list-static	2005-01-10 17:29:39.313910296 -0800
+++ 25-akpm/fs/ext2/xattr.c	2005-01-10 17:29:39.318909536 -0800
@@ -137,17 +137,6 @@ ext2_xattr_handler(int name_index)
 }
 
 /*
- * Inode operation listxattr()
- *
- * dentry->d_inode->i_sem: don't care
- */
-ssize_t
-ext2_listxattr(struct dentry *dentry, char *buffer, size_t size)
-{
-	return ext2_xattr_list(dentry->d_inode, buffer, size);
-}
-
-/*
  * ext2_xattr_get()
  *
  * Copy an extended attribute into the buffer
@@ -260,7 +249,7 @@ cleanup:
  * Returns a negative error number on failure, or the number of bytes
  * used / required on success.
  */
-int
+static int
 ext2_xattr_list(struct inode *inode, char *buffer, size_t buffer_size)
 {
 	struct buffer_head *bh = NULL;
@@ -335,6 +324,17 @@ cleanup:
 }
 
 /*
+ * Inode operation listxattr()
+ *
+ * dentry->d_inode->i_sem: don't care
+ */
+ssize_t
+ext2_listxattr(struct dentry *dentry, char *buffer, size_t size)
+{
+	return ext2_xattr_list(dentry->d_inode, buffer, size);
+}
+
+/*
  * If the EXT2_FEATURE_COMPAT_EXT_ATTR feature of this file system is
  * not set, set it.
  */
diff -puN fs/ext2/xattr.h~fs-ext2-xattrc-make-ext2_xattr_list-static fs/ext2/xattr.h
--- 25/fs/ext2/xattr.h~fs-ext2-xattrc-make-ext2_xattr_list-static	2005-01-10 17:29:39.314910144 -0800
+++ 25-akpm/fs/ext2/xattr.h	2005-01-10 17:29:39.318909536 -0800
@@ -66,7 +66,6 @@ extern struct xattr_handler ext2_xattr_s
 extern ssize_t ext2_listxattr(struct dentry *, char *, size_t);
 
 extern int ext2_xattr_get(struct inode *, int, const char *, void *, size_t);
-extern int ext2_xattr_list(struct inode *, char *, size_t);
 extern int ext2_xattr_set(struct inode *, int, const char *, const void *, size_t, int);
 
 extern void ext2_xattr_delete_inode(struct inode *);
@@ -87,12 +86,6 @@ ext2_xattr_get(struct inode *inode, int 
 }
 
 static inline int
-ext2_xattr_list(struct inode *inode, char *buffer, size_t size)
-{
-	return -EOPNOTSUPP;
-}
-
-static inline int
 ext2_xattr_set(struct inode *inode, int name_index, const char *name,
 	       const void *value, size_t size, int flags)
 {
_
